@@ -1,4 +1,4 @@
-/* $Id: auvoxware.c 234 2007-03-14 03:32:50Z jon $ */
+/* $Id: auvoxware.c 270 2007-11-22 23:53:23Z steve_mcintyre $ */
 
 /*
    SCCS: @(#) auvoxware.c 11.4 95/04/14 
@@ -197,10 +197,6 @@ static int debug_msg_indentation = 0;
 #include <audio/Aproto.h>
 #include "au.h"
 
-#ifdef sco
-static AuBool scoAudioBlocked = AuFalse;
-#endif /* sco */
-
 static AuBool processFlowEnabled;
 static void disableProcessFlow(void);
 static void closeDevice(void);
@@ -232,7 +228,7 @@ static int inmixerfd = -1;      /* The input device mixer device */
 static int devmask = 0;         /* Bitmask for supported mixer devices */
 static int recmask = 0;         /* Supported recording sources */
 
-int VOXMixerInit = TRUE;        /* overridden by nasd.conf */
+int VOXMixerInit   = FALSE;     /* overridden by nasd.conf */
 int VOXReInitMixer = FALSE;     /* overridden by nasd.conf */
 
 /* end of VOXware driver mixer control variables */
@@ -316,19 +312,94 @@ static void setPhysicalOutputGain(AuFixedPoint gain);
 static void setPhysicalInputGainAndLineMode(AuFixedPoint gain,
                                             AuUint8 lineMode);
 
+
+/* internal funtions for enabling/disabling intervalProc using sigaction
+   semantics */
+
+static void intervalProc(int sig);
+
+/* use this in disableIntervalProc() instead of SIG_IGN for testing */
+#if 0
+static void ignoreProc(int sig)
+{
+  osLogMsg("SIGNAL IGNORE: ENTRY\n");
+  return;
+}
+#endif
+
+static void enableIntervalProc(void)
+{
+    struct sigaction action;
+
+    action.sa_handler = (void (*)(int))intervalProc;
+    action.sa_flags = 0;
+    sigemptyset(&action.sa_mask);
+    sigaddset(&action.sa_mask, SIGALRM);
+
+    if (sigaction(SIGALRM, &action, NULL) == -1)
+        {
+          osLogMsg("enableIntervalProc: sigaction failed: %s\n", 
+                   strerror(errno));
+        }
+  
+    return;
+}
+
+static void disableIntervalProc(void)
+{
+    struct sigaction action;
+
+    action.sa_handler = (void (*)(int))SIG_IGN;
+    action.sa_flags = 0;
+
+    if (sigaction(SIGALRM, &action, NULL) == -1)
+        {
+          osLogMsg("disableIntervalProc: sigaction failed: %s\n", 
+                   strerror(errno));
+        }
+  
+    return;
+}
+
+static AuBool audioBlocked = AuFalse;
+
+AuBlock _AuBlockAudio(void)
+{                                                          
+    sigset_t set;
+
+    audioBlocked = AuTrue;
+    sigemptyset(&set); 
+    sigaddset(&set, SIGALRM);
+    sigprocmask(SIG_BLOCK, &set, NULL);
+    return 0;
+}
+
+void _AuUnBlockAudio(AuBlock _x)
+{
+    sigset_t set;
+
+    audioBlocked = AuFalse;
+    sigemptyset(&set);
+    sigaddset(&set, SIGALRM);
+    sigprocmask(SIG_UNBLOCK, &set, NULL);
+    return;
+}
+
+
+/* ### SCO ### */
 #ifdef sco
 
 AuBlock
 AuBlockAudio(void)
 {
-    scoAudioBlocked = AuTrue;
+    audioBlocked = AuTrue;
     return 0;
 }
 
 void
 AuUnBlockAudio(AuBlock id)
 {
-    scoAudioBlocked = AuFalse;
+    audioBlocked = AuFalse;
 }
 
 #endif /* sco */
@@ -431,6 +502,10 @@ readMixerInputGain(void)
             }
             break;
 
+        case useMixerNone:
+            return sndStatIn.gain;
+            break;
+
         default:
             osLogMsg("readMixerInputGain: "
                      "unknown value %d of recControlMode\n", recControlMode);
@@ -631,7 +706,7 @@ setTimer(AuInt32 rate)
     AuInt32 foo;
     struct itimerval ntval, otval;
 
-    if (NasConfig.DoDebug) {
+    if (NasConfig.DoDebug > 5) {
         osLogMsg("setTimer(rate = %d);\n", rate);
         IDENTMSG;
     }
@@ -1030,9 +1105,7 @@ serverReset(void)
     }
 
     setTimer(0);
-#ifndef sco
-    signal(SIGALRM, SIG_IGN);
-#endif /* sco */
+    disableIntervalProc(); 
 
 #if defined(AUDIO_DRAIN)
     if (sndStatOut.isPCSpeaker)
@@ -1060,48 +1133,21 @@ serverReset(void)
     }
 }
 
-
 static void
 intervalProc(int sig)
 {
     extern void AuProcessData();
 
-#ifndef sco
-    signal(SIGALRM, SIG_IGN);
+#if !defined(sco)
+    setTimer(0);                /* turn off the timer here so that
+                                   a potential race is avoided */
 
-#if defined(linux) || defined(__CYGWIN__)
-    /* this looks funny and stupid, but BSD not only provide
-     * reliable signals but also block this signal while executing
-     * this handler
-     * So the timer may expires before the handler is ready
-     * and it will be recalled immediately again preventing us
-     * executing normal stuff
-     * this happens if we get blocked by the write, i.e.
-     * It will happen as our timer is a little bit to fast
-     * so we should really ignore signals
-     */
-    {
-        sigset_t set;
-        sigemptyset(&set);
-        sigaddset(&set, SIGALRM);
-        sigprocmask(SIG_UNBLOCK, &set, NULL);
-    }
-#endif
-    if (processFlowEnabled) {
+    if (processFlowEnabled)
         AuProcessData();
-#if defined(linux) || defined(__CYGWIN__)
-        /* block the signal again */
-        {
-            sigset_t set;
-            sigemptyset(&set);
-            sigaddset(&set, SIGALRM);
-            sigprocmask(SIG_BLOCK, &set, NULL);
-        }
-#endif
-        signal(SIGALRM, intervalProc);
-    }
+
+    setTimer(sndStatOut.curSampleRate);
 #else
-    if (!scoAudioBlocked && processFlowEnabled)
+    if (!audioBlocked && processFlowEnabled)
         AuProcessData();
 #endif /* sco */
 }
@@ -1263,38 +1309,29 @@ enableProcessFlow(void)
             setMixerDefaults();
         }
     }
-#ifdef sco
+
+#if defined(sco)
     if (!processFlowEnabled) {
-#endif /* sco */
-
         processFlowEnabled = AuTrue;
-
-#ifndef sco
-        signal(SIGALRM, intervalProc);
-        if (NasConfig.DoDebug > 1) {
-            osLogMsg("enableProcessFlow() - set SIGALRM handler to intervalProc\n");
-        }
-#else
         setTimer(sndStatOut.curSampleRate);
+    }
+#else  /* sco */
+    processFlowEnabled = AuTrue;
 #endif /* sco */
 
-#ifdef sco
-    }
-#endif /* sco */
 }
 
 static void
 disableProcessFlow(void)
 {
-
 #ifndef sco
     int rate;
-    signal(SIGALRM, SIG_IGN);
 #endif /* sco */
 
     if (NasConfig.DoDebug) {
         osLogMsg("disableProcessFlow() - starting\n");
     }
+
 #ifdef sco
     if (processFlowEnabled) {
 #endif /* sco */
@@ -1335,7 +1372,7 @@ disableProcessFlow(void)
 }
 
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
+#if defined(__GNUC__) && !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
         static void
@@ -1350,7 +1387,7 @@ monoToStereoLinearSigned16LSB(AuUint32 numSamples)
     }
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
+#if defined(__GNUC__) && !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
         static void
@@ -1413,7 +1450,7 @@ writePhysicalOutputsMono(void)
     AuUnBlockAudio(l);
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
+#if defined(__GNUC__) && !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
         static void
@@ -1428,7 +1465,7 @@ stereoToMonoLinearSigned16LSB(AuUint32 numSamples)
     }
 }
 
-#if defined(__GNUC__) && !defined(linux) && !defined(USL) && !defined(__CYGWIN__)
+#if defined(__GNUC__) && !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__) && !defined(USL) && !defined(__CYGWIN__)
 inline
 #endif
         static void
@@ -1954,7 +1991,9 @@ AuInitPhysicalDevices(void)
         return AuFalse;
     }
 #else
-    signal(SIGALRM, intervalProc);
+
+    enableIntervalProc(); 
+
 #endif /* sco */
 
     setTimer(0);
